==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/pol_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['section_add_comment'] = 					"add comment";
$lang['hdr_options'] = 							"options";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_forthcoming_polls'] = 				"forthcoming polls";
$lang['hdr_archive_polls'] = 					"archive polls";
$lang['hdr_comment_preview'] = 					"comment preview";


//SUBMIT
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_save'] = 							"save";


//HREF
$lang['href_add'] = 							"add poll";
$lang['href_list'] = 							"list";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_edit_poll_option'] =					"edit or delete a poll option";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the group. Reply in group language only.";
$lang['txt_check_spelling'] =					"Check Spelling";

//$lang['href_recommend_this'] = 					"tip this";
//$lang['href_unrecommend_this'] =				"remove tip";
//$lang['href_unwatch_this'] =					"remove mark";
//$lang['href_watch_this'] =						"add mark";


?>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/pol_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['section_add_comment'] = 					"add comment";
$lang['hdr_options'] = 							"options";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_forthcoming_polls'] = 				"forthcoming polls";
$lang['hdr_archive_polls'] = 					"archive polls";
$lang['hdr_comment_preview'] = 					"comment preview";
$lang['hdr_tag'] = 								"tags";


//SUBMIT
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_save'] = 							"save";
$lang['sub_update_tag'] = 						"update my tags";


//HREF
$lang['href_add'] = 							"add poll";
$lang['href_list'] = 							"list";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_edit_poll_option'] =					"edit or delete a poll option";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the group. Reply in group language only.";
$lang['txt_check_spelling'] =					"Check Spelling";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_tag_intro'] = 						"This poll has been tagged with";
$lang['txt_tag_network'] = 						"My network have tagged this poll with";
$lang['txt_tag_group'] = 						"This group has tagged this poll with";
$lang['txt_non_member'] = 						"NON MEMBER";
$lang['txt_joined'] = 							"Joined";
$lang['txt_hometown'] = 						"Hometown";

?>
